import logging
import html
from telegram import Update
from telegram.ext import ContextTypes
from .base import InfoCommandsBase

logger = logging.getLogger(__name__)

class RiskCommands(InfoCommandsBase):
    """Handles all risk management-related commands."""

    async def risk_command(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
        """Handle the /risk command to show advanced risk metrics."""
        chat_id = update.effective_chat.id
        if not self._is_authorized(update):
            return
        
        try:
            # Get current balance for context
            balance = self.trading_engine.get_balance()
            current_balance = 0
            if balance and balance.get('total'):
                current_balance = float(balance['total'].get('USDC', 0))
            
            # Get risk metrics and basic stats
            stats = self.trading_engine.get_stats()
            if not stats:
                await context.bot.send_message(chat_id=chat_id, text="❌ Could not load trading statistics")
                return
                
            risk_metrics = stats.get_risk_metrics()
            basic_stats = stats.get_basic_stats()
            
            # Check if we have enough data for risk calculations
            if basic_stats['completed_trades'] < 2:
                await context.bot.send_message(chat_id=chat_id, text=
                    "📊 <b>Risk Analysis</b>\n\n"
                    "📭 <b>Insufficient Data</b>\n\n"
                    f"• Current completed trades: {html.escape(str(basic_stats['completed_trades']))}\n"
                    f"• Required for risk analysis: 2+ trades\n"
                    f"• Daily balance snapshots: {html.escape(str(stats.get_daily_balance_record_count()))}\n\n"
                    "💡 <b>To enable risk analysis:</b>\n"
                    "• Complete more trades to generate returns data\n"
                    "• Bot automatically records daily balance snapshots\n"
                    "• Risk metrics will be available after sufficient trading history\n\n"
                    "📈 Use /stats for current performance metrics",
                    parse_mode='HTML'
                )
                return
            
            # Get risk metric values with safe defaults
            sharpe_ratio = risk_metrics.get('sharpe_ratio')
            max_drawdown_pct = risk_metrics.get('max_drawdown_live_percentage', 0.0)
            
            # Format values safely
            sharpe_str = f"{sharpe_ratio:.3f}" if sharpe_ratio is not None else "N/A"
            
            # Format the risk analysis message
            risk_text = f"""
📊 <b>Risk Analysis & Advanced Metrics</b>

🎯 <b>Risk-Adjusted Performance:</b>
• Sharpe Ratio: {sharpe_str}
• Profit Factor: {risk_metrics.get('profit_factor', 0):.2f}
• Win Rate: {risk_metrics.get('win_rate', 0):.1f}%

📉 <b>Drawdown Analysis:</b>
• Maximum Drawdown: {max_drawdown_pct:.2f}%
• Max Consecutive Losses: {risk_metrics.get('max_consecutive_losses', 0)}

💰 <b>Portfolio Context:</b>
• Current Balance: ${current_balance:,.2f}
• Initial Balance: ${basic_stats['initial_balance']:,.2f}
• Total P&L: ${basic_stats['total_pnl']:,.2f}
• Days Active: {html.escape(str(basic_stats['days_active']))}

📊 <b>Risk Interpretation:</b>
"""
            
            # Add interpretive guidance
            if sharpe_ratio is not None:
                if sharpe_ratio > 2.0:
                    risk_text += "• 🟢 <b>Excellent</b> risk-adjusted returns (Sharpe > 2.0)\n"
                elif sharpe_ratio > 1.0:
                    risk_text += "• 🟡 <b>Good</b> risk-adjusted returns (Sharpe > 1.0)\n"
                elif sharpe_ratio > 0.5:
                    risk_text += "• 🟠 <b>Moderate</b> risk-adjusted returns (Sharpe > 0.5)\n"
                elif sharpe_ratio > 0:
                    risk_text += "• 🔴 <b>Poor</b> risk-adjusted returns (Sharpe > 0)\n"
                else:
                    risk_text += "• ⚫ <b>Negative</b> risk-adjusted returns (Sharpe < 0)\n"
            else:
                risk_text += "• ⚪ <b>Insufficient data</b> for Sharpe ratio calculation\n"
            
            if max_drawdown_pct < 5:
                risk_text += "• 🟢 <b>Low</b> maximum drawdown (< 5%)\n"
            elif max_drawdown_pct < 15:
                risk_text += "• 🟡 <b>Moderate</b> maximum drawdown (< 15%)\n"
            elif max_drawdown_pct < 30:
                risk_text += "• 🟠 <b>High</b> maximum drawdown (< 30%)\n"
            else:
                risk_text += "• 🔴 <b>Very High</b> maximum drawdown (> 30%)\n"
            
            # Add profit factor interpretation
            profit_factor = risk_metrics.get('profit_factor', 0)
            if profit_factor > 2.0:
                risk_text += "• 🟢 <b>Excellent</b> profit factor (> 2.0)\n"
            elif profit_factor > 1.5:
                risk_text += "• 🟡 <b>Good</b> profit factor (> 1.5)\n"
            elif profit_factor > 1.0:
                risk_text += "• 🟠 <b>Profitable</b> but low profit factor (> 1.0)\n"
            else:
                risk_text += "• 🔴 <b>Unprofitable</b> trading strategy (< 1.0)\n"
            
            risk_text += f"""

💡 <b>Risk Definitions:</b>
• <b>Sharpe Ratio:</b> Risk-adjusted return (excess return / volatility)
• <b>Profit Factor:</b> Total winning trades / Total losing trades
• <b>Win Rate:</b> Percentage of profitable trades
• <b>Max Drawdown:</b> Largest peak-to-trough decline
• <b>Max Consecutive Losses:</b> Longest streak of losing trades

📈 <b>Data Based On:</b>
• Completed Trades: {html.escape(str(basic_stats['completed_trades']))}
• Trading Period: {html.escape(str(basic_stats['days_active']))} days

🔄 Use /stats for trading performance metrics
            """
            
            await context.bot.send_message(chat_id=chat_id, text=risk_text.strip(), parse_mode='HTML')
            
        except Exception as e:
            error_message = f"❌ Error processing risk command: {str(e)}"
            await context.bot.send_message(chat_id=chat_id, text=error_message)
            logger.error(f"Error in risk command: {e}")
